@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2013 – 2017 Red Hat, Inc.
+ * Copyright © 2013 – 2018 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -62,10 +62,11 @@ photos_create_collection_job_query_executed (GObject *source_object, GAsyncResul
   GTask *task = G_TASK (user_data);
   TrackerSparqlConnection *connection = TRACKER_SPARQL_CONNECTION (source_object);
   GError *error;
-  GVariant *variant;
-  GVariant *child;
-  gchar *key = NULL;
-  gchar *val = NULL;
+  g_autoptr (GVariant) key_variant = NULL;
+  g_autoptr (GVariant) val_variant = NULL;
+  g_autoptr (GVariant) variant = NULL;
+  g_autofree gchar *key = NULL;
+  g_autofree gchar *val = NULL;
 
   error = NULL;
   variant = tracker_sparql_connection_update_blank_finish (connection, res, &error);
@@ -75,35 +76,37 @@ photos_create_collection_job_query_executed (GObject *source_object, GAsyncResul
       return;
     }
 
-  child = g_variant_get_child_value (variant, 0); /* variant is now aa{ss} */
-  g_variant_unref (variant);
-  variant = child;
+  {
+    g_autoptr (GVariant) parent = NULL;
 
-  child = g_variant_get_child_value (variant, 0); /* variant is now s{ss} */
-  g_variant_unref (variant);
-  variant = child;
+    parent = g_steal_pointer (&variant);
+    variant = g_variant_get_child_value (parent, 0); /* variant is now aa{ss} */
+  }
 
-  child = g_variant_get_child_value (variant, 0); /* variant is now {ss} */
-  g_variant_unref (variant);
-  variant = child;
+  {
+    g_autoptr (GVariant) parent = NULL;
 
-  child = g_variant_get_child_value (variant, 0);
-  key = g_variant_dup_string (child, NULL);
-  g_variant_unref (child);
+    parent = g_steal_pointer (&variant);
+    variant = g_variant_get_child_value (parent, 0); /* variant is now a{ss} */
+  }
 
-  child = g_variant_get_child_value (variant, 1);
-  val = g_variant_dup_string (child, NULL);
-  g_variant_unref (child);
+  {
+    g_autoptr (GVariant) parent = NULL;
 
-  g_variant_unref (variant);
+    parent = g_steal_pointer (&variant);
+    variant = g_variant_get_child_value (parent, 0); /* variant is now {ss} */
+  }
+
+  key_variant = g_variant_get_child_value (variant, 0);
+  key = g_variant_dup_string (key_variant, NULL);
+
+  val_variant = g_variant_get_child_value (variant, 1);
+  val = g_variant_dup_string (val_variant, NULL);
 
   if (g_strcmp0 (key, "res") == 0)
     g_task_return_pointer (task, g_strdup (val), g_free);
   else
     g_task_return_new_error (task, PHOTOS_ERROR, 0, "Failed to parse GVariant");
-
-  g_free (val);
-  g_free (key);
 }
 
 
@@ -218,8 +221,8 @@ photos_create_collection_job_run (PhotosCreateCollectionJob *self,
                                   gpointer user_data)
 {
   GApplication *app;
-  GTask *task;
-  PhotosQuery *query = NULL;
+  g_autoptr (GTask) task = NULL;
+  g_autoptr (PhotosQuery) query = NULL;
   PhotosSearchContextState *state;
 
   g_return_if_fail (PHOTOS_IS_CREATE_COLLECTION_JOB (self));
@@ -246,6 +249,5 @@ photos_create_collection_job_run (PhotosCreateCollectionJob *self,
                                      g_object_unref);
 
  out:
-  g_clear_object (&query);
-  g_object_unref (task);
+  return;
 }
