@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2013 – 2017 Red Hat, Inc.
+ * Copyright © 2013 – 2018 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -57,7 +57,6 @@ static const gchar *REQUIRED_GEGL_OPS[] =
   "gegl:load",
   "gegl:noise-reduction",
   "gegl:nop",
-  "gegl:save-pixbuf",
   "gegl:scale-ratio",
   "gegl:shadows-highlights",
   "gegl:unsharp-mask",
@@ -102,6 +101,7 @@ photos_gegl_buffer_apply_orientation (GeglBuffer *buffer_original, GQuark orient
   GeglRectangle bbox_original;
   gint bpp;
 
+  g_return_val_if_fail (GEGL_IS_BUFFER (buffer_original), NULL);
   g_return_val_if_fail (orientation == PHOTOS_ORIENTATION_BOTTOM
                         || orientation == PHOTOS_ORIENTATION_BOTTOM_MIRROR
                         || orientation == PHOTOS_ORIENTATION_LEFT
@@ -388,6 +388,8 @@ photos_gegl_buffer_new_from_pixbuf (GdkPixbuf *pixbuf)
   gint width;
   const guint8 *pixels;
 
+  g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), NULL);
+
   height = gdk_pixbuf_get_height (pixbuf);
   width = gdk_pixbuf_get_width (pixbuf);
   gegl_rectangle_set (&bbox, 0, 0, (guint) width, (guint) height);
@@ -505,20 +507,63 @@ photos_gegl_buffer_zoom_finish (GeglBuffer *buffer, GAsyncResult *res, GError **
 }
 
 
+gchar *
+photos_gegl_compute_checksum_for_buffer  (GChecksumType checksum_type, GeglBuffer *buffer)
+{
+  const Babl *format;
+  g_autoptr (GChecksum) checksum = NULL;
+  GeglRectangle bbox;
+  GeglRectangle roi;
+  const gchar *str;
+  gchar *ret_val = NULL;
+  gint bpp;
+  gint i;
+  gint stride;
+  g_autofree guchar *buf = NULL;
+
+  checksum = g_checksum_new (checksum_type);
+  if (checksum == NULL)
+    goto out;
+
+  bbox = *gegl_buffer_get_extent (buffer);
+
+  roi.x = bbox.x;
+  roi.y = bbox.y;
+  roi.height = 1;
+  roi.width = bbox.width;
+
+  format = gegl_buffer_get_format (buffer);
+  bpp = babl_format_get_bytes_per_pixel (format);
+
+  if (bpp > 0 && bbox.width > 0 && bbox.width > G_MAXINT / bpp)
+    goto out;
+
+  stride = bpp * bbox.width;
+  buf = (guchar *) g_malloc0_n ((gsize) bbox.width, (gsize) bpp);
+
+  for (i = 0; i < bbox.height; i++)
+    {
+      gegl_buffer_get (buffer, &roi, 1.0, format, buf, stride, GEGL_ABYSS_NONE);
+      g_checksum_update (checksum, buf, (gssize) stride);
+      roi.y++;
+    }
+
+  str = g_checksum_get_string (checksum);
+  ret_val = g_strdup (str);
+
+ out:
+  return ret_val;
+}
+
+
 GdkPixbuf *
 photos_gegl_create_pixbuf_from_node (GeglNode *node)
 {
   GdkPixbuf *pixbuf = NULL;
-  GeglNode *graph;
-  g_autoptr (GeglNode) save_pixbuf = NULL;
+  g_autoptr (GeglBuffer) buffer = NULL;
 
-  graph = gegl_node_get_parent (node);
-  save_pixbuf = gegl_node_new_child (graph,
-                                     "operation", "gegl:save-pixbuf",
-                                     "pixbuf", &pixbuf,
-                                     NULL);
-  gegl_node_link_many (node, save_pixbuf, NULL);
-  gegl_node_process (save_pixbuf);
+  buffer = photos_gegl_get_buffer_from_node (node, NULL);
+  pixbuf = photos_gegl_pixbuf_new_from_buffer (buffer);
 
   return pixbuf;
 }
@@ -605,8 +650,6 @@ photos_gegl_init (void)
   gint threads;
   guint n_processors;
 
-  gegl_init (NULL, NULL);
-
   n_processors = g_get_num_processors ();
   g_return_if_fail (n_processors > 0);
 
@@ -622,6 +665,8 @@ photos_gegl_init (void)
   g_object_set (config, "application-license", "GPL3", NULL);
   g_object_set (config, "threads", threads, NULL);
   g_object_set (config, "use-opencl", FALSE, NULL);
+
+  gegl_init (NULL, NULL);
 }
 
 
@@ -649,6 +694,46 @@ photos_gegl_init_fishes (void)
 }
 
 
+GdkPixbuf *
+photos_gegl_pixbuf_new_from_buffer (GeglBuffer *buffer)
+{
+  const Babl *format_buffer;
+  const Babl *format_pixbuf;
+  g_autoptr (GBytes) bytes = NULL;
+  GdkPixbuf *pixbuf = NULL;
+  GeglRectangle bbox;
+  gboolean has_alpha;
+  gint stride;
+  gpointer buf = NULL;
+  gsize size;
+
+  g_return_val_if_fail (GEGL_IS_BUFFER (buffer), NULL);
+
+  bbox = *gegl_buffer_get_extent (buffer);
+  format_buffer = gegl_buffer_get_format (buffer);
+  has_alpha = (gboolean) babl_format_has_alpha (format_buffer);
+
+  if (has_alpha)
+    format_pixbuf = babl_format ("R'G'B'A u8");
+  else
+    format_pixbuf = babl_format ("R'G'B' u8");
+
+  stride = gdk_pixbuf_calculate_rowstride (GDK_COLORSPACE_RGB, has_alpha, 8, bbox.width, bbox.height);
+  if (stride == -1)
+    goto out;
+
+  buf = g_malloc0_n ((gsize) bbox.height, (gsize) stride);
+  gegl_buffer_get (buffer, &bbox, 1.0, format_pixbuf, buf, stride, GEGL_ABYSS_NONE);
+
+  size = (gsize) bbox.height * (gsize) stride;
+  bytes = g_bytes_new_take (buf, size);
+  pixbuf = gdk_pixbuf_new_from_bytes (bytes, GDK_COLORSPACE_RGB, has_alpha, 8, bbox.width, bbox.height, stride);
+
+ out:
+  return pixbuf;
+}
+
+
 static gboolean
 photos_gegl_processor_process_idle (gpointer user_data)
 {
