@@ -2,10 +2,10 @@
  * Photos - access, organize and share your photos on GNOME
  * Copyright © 2013 – 2017 Red Hat, Inc.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,9 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* Based on code from:
@@ -25,14 +23,11 @@
 
 #include "config.h"
 
-#include <gio/gio.h>
 #include <glib.h>
 #include <tracker-sparql.h>
 
 #include "photos-query.h"
 #include "photos-query-builder.h"
-#include "photos-search-context.h"
-#include "photos-selection-controller.h"
 #include "photos-set-collection-job.h"
 #include "photos-tracker-queue.h"
 #include "photos-update-mtime-job.h"
@@ -41,13 +36,11 @@
 struct _PhotosSetCollectionJob
 {
   GObject parent_instance;
-  PhotosSelectionController *sel_cntrlr;
-  PhotosSetCollectionJobCallback callback;
+  GError *queue_error;
   PhotosTrackerQueue *queue;
   gboolean setting;
   gchar *collection_urn;
   gint running_jobs;
-  gpointer user_data;
 };
 
 enum
@@ -64,34 +57,38 @@ G_DEFINE_TYPE (PhotosSetCollectionJob, photos_set_collection_job, G_TYPE_OBJECT)
 static void
 photos_set_collection_job_update_mtime (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
+  GTask *task = G_TASK (user_data);
   PhotosUpdateMtimeJob *job = PHOTOS_UPDATE_MTIME_JOB (source_object);
-  PhotosSetCollectionJob *self = PHOTOS_SET_COLLECTION_JOB (user_data);
   GError *error = NULL;
 
   photos_update_mtime_job_finish (job, res, &error);
   if (error != NULL)
     {
-      g_warning ("Unable to update mtime: %s", error->message);
-      g_error_free (error);
+      g_task_return_error (task, error);
+      goto out;
     }
 
-  if (self->callback != NULL)
-    (*self->callback) (self->user_data);
+  g_task_return_boolean (task, TRUE);
 
-  g_object_unref (self);
+ out:
+  g_object_unref (task);
 }
 
 
 static void
-photos_set_collection_job_job_collector (PhotosSetCollectionJob *self)
+photos_set_collection_job_job_collector (PhotosSetCollectionJob *self, GTask *task)
 {
+  GCancellable *cancellable;
+
+  cancellable = g_task_get_cancellable (task);
+
   self->running_jobs--;
   if (self->running_jobs == 0)
     {
       PhotosUpdateMtimeJob *job;
 
       job = photos_update_mtime_job_new (self->collection_urn);
-      photos_update_mtime_job_run (job, NULL, photos_set_collection_job_update_mtime, g_object_ref (self));
+      photos_update_mtime_job_run (job, cancellable, photos_set_collection_job_update_mtime, g_object_ref (task));
       g_object_unref (job);
     }
 }
@@ -100,20 +97,22 @@ photos_set_collection_job_job_collector (PhotosSetCollectionJob *self)
 static void
 photos_set_collection_job_query_executed (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
-  PhotosSetCollectionJob *self = PHOTOS_SET_COLLECTION_JOB (user_data);
+  PhotosSetCollectionJob *self;
+  GTask *task = G_TASK (user_data);
   TrackerSparqlConnection *connection = TRACKER_SPARQL_CONNECTION (source_object);
   GError *error;
 
+  self = PHOTOS_SET_COLLECTION_JOB (g_task_get_source_object (task));
+
   error = NULL;
   tracker_sparql_connection_update_finish (connection, res, &error);
   if (error != NULL)
     {
-      g_warning ("Unable to add item to collection: %s", error->message);
-      g_error_free (error);
+      g_task_return_error (task, error);
       return;
     }
 
-  photos_set_collection_job_job_collector (self);
+  photos_set_collection_job_job_collector (self, task);
 }
 
 
@@ -122,7 +121,6 @@ photos_set_collection_job_dispose (GObject *object)
 {
   PhotosSetCollectionJob *self = PHOTOS_SET_COLLECTION_JOB (object);
 
-  g_clear_object (&self->sel_cntrlr);
   g_clear_object (&self->queue);
 
   G_OBJECT_CLASS (photos_set_collection_job_parent_class)->dispose (object);
@@ -134,6 +132,7 @@ photos_set_collection_job_finalize (GObject *object)
 {
   PhotosSetCollectionJob *self = PHOTOS_SET_COLLECTION_JOB (object);
 
+  g_clear_error (&self->queue_error);
   g_free (self->collection_urn);
 
   G_OBJECT_CLASS (photos_set_collection_job_parent_class)->finalize (object);
@@ -165,8 +164,7 @@ photos_set_collection_job_set_property (GObject *object, guint prop_id, const GV
 static void
 photos_set_collection_job_init (PhotosSetCollectionJob *self)
 {
-  self->sel_cntrlr = photos_selection_controller_dup_singleton ();
-  self->queue = photos_tracker_queue_dup_singleton (NULL, NULL);
+  self->queue = photos_tracker_queue_dup_singleton (NULL, &self->queue_error);
 }
 
 
@@ -208,30 +206,43 @@ photos_set_collection_job_new (const gchar *collection_urn, gboolean setting)
 }
 
 
+gboolean
+photos_set_collection_job_finish (PhotosSetCollectionJob *self, GAsyncResult *res, GError **error)
+{
+  GTask *task;
+
+  g_return_val_if_fail (PHOTOS_IS_SET_COLLECTION_JOB (self), FALSE);
+
+  g_return_val_if_fail (g_task_is_valid (res, self), FALSE);
+  task = G_TASK (res);
+
+  g_return_val_if_fail (g_task_get_source_tag (task) == photos_set_collection_job_run, FALSE);
+  g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
+  return g_task_propagate_boolean (task, error);
+}
+
+
 void
 photos_set_collection_job_run (PhotosSetCollectionJob *self,
-                               PhotosSetCollectionJobCallback callback,
+                               PhotosSearchContextState *state,
+                               GList *urns,
+                               GCancellable *cancellable,
+                               GAsyncReadyCallback callback,
                                gpointer user_data)
 {
-  GApplication *app;
   GList *l;
-  GList *urns;
-  PhotosSearchContextState *state;
+  GTask *task = NULL;
+
+  task = g_task_new (self, cancellable, callback, user_data);
+  g_task_set_source_tag (task, photos_set_collection_job_run);
 
   if (G_UNLIKELY (self->queue == NULL))
     {
-      if (callback != NULL)
-        (*callback) (user_data);
-      return;
+      g_task_return_error (task, g_error_copy (self->queue_error));
+      goto out;
     }
 
-  self->callback = callback;
-  self->user_data = user_data;
-
-  app = g_application_get_default ();
-  state = photos_search_context_get_state (PHOTOS_SEARCH_CONTEXT (app));
-
-  urns = photos_selection_controller_get_selection (self->sel_cntrlr);
   for (l = urns; l != NULL; l = l->next)
     {
       PhotosQuery *query = NULL;
@@ -244,10 +255,13 @@ photos_set_collection_job_run (PhotosSetCollectionJob *self,
       query = photos_query_builder_set_collection_query (state, urn, self->collection_urn, self->setting);
       photos_tracker_queue_update (self->queue,
                                    query,
-                                   NULL,
+                                   cancellable,
                                    photos_set_collection_job_query_executed,
-                                   g_object_ref (self),
+                                   g_object_ref (task),
                                    g_object_unref);
       g_object_unref (query);
     }
+
+ out:
+  g_clear_object (&task);
 }
